diff --git a/src/FACT_jobs.jl b/src/FACT_jobs.jl
index 72758481d706965d0a4745b48a8d1f152d7cf3c8..4311f43e7a035680a9a980c57a4da1d6242d97b8 100644
--- a/src/FACT_jobs.jl
+++ b/src/FACT_jobs.jl
@@ -94,7 +94,7 @@ function us_qcew(conn::MySQL.Connection, selection::Dict)
         end
 
         # prepare query
-        query = "SELECT Naics as industry, (Jan_jobs+Feb_jobs+Mar_jobs+Apr_jobs+May_jobs+Jun_jobs+Jul_jobs+Aug_jobs+Sep_jobs+Oct_jobs+Nov_jobs+Dec_jobs)/12 as jobs FROM QCEW WHERE Year = "*string(year)*" AND GeoID = '"*full_id*"' AND Agglvl_code = '"*string(agglvl_code)*"';"
+        query = "SELECT Naics as industry, (Jan_jobs+Feb_jobs+Mar_jobs+Apr_jobs+May_jobs+Jun_jobs+Jul_jobs+Aug_jobs+Sep_jobs+Oct_jobs+Nov_jobs+Dec_jobs)/12 as jobs FROM QCEW WHERE Year = $year AND GeoID = '$full_id' AND Agglvl_code = '$agglvl_code';"
         # execute
         result = query_connection(conn, query)
         # Check if the 'industry' column exists
diff --git a/src/FACT_elevation.jl b/src/FACT_elevation.jl
index 231a70c443522cbe6f3f637eab2f65eacedc517a..c5f7942341b204f11e8c33e334e3dd2525e54b10 100644
--- a/src/FACT_elevation.jl
+++ b/src/FACT_elevation.jl
@@ -33,13 +33,13 @@ function elevation_data_full(ws_host_port::String, selection::Dict)
     entropy_elevations = Float64[]
     
     for (id, shape) in zip(geo_id, shape_obj)
-        # setting starting values to missing
-        min_elevation = missing
-        max_elevation = missing
-        mean_elevation = missing
-        std_elevation = missing
-        median_elevation = missing
-        entropy_elevation = missing
+        # setting starting values to nothing
+        min_elevation = nothing
+        max_elevation = nothing
+        mean_elevation = nothing
+        std_elevation = nothing
+        median_elevation = nothing
+        entropy_elevation = nothing
 
 
         # Construct the JSON payload
diff --git a/src/FACT_road.jl b/src/FACT_road.jl
index 792ef09b61720863870db89c741e0c48b5e3f707..88819f30cd7b353a7778a9fec5499edcbeb2342d 100644
--- a/src/FACT_road.jl
+++ b/src/FACT_road.jl
@@ -49,7 +49,7 @@ function travel_time_in_minutes(ws_host_port::String, selection::Dict)
             # Construct the request URL
             url = "$ws_host_port/route/v1/driving/$(start_longitude),$(start_latitude);$(end_longitude),$(end_latitude)?overview=false"
 
-            travel_time = missing  # Use `missing` to represent null in Julia
+            travel_time = nothing  # Use `nothing` to represent null in Julia
 
             try
                 # Make the request